# ys-dl

Command-line program to download images from [Genshin Impact Community](https://ys.mihoyo.com/).

![GitHub Workflow Status](https://img.shields.io/github/workflow/status/XavierJiezou/ys-dl/Release)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/c2f85c8d6b8a4892b40059703f087eab)](https://www.codacy.com/gh/XavierJiezou/ys-dl/dashboard?utm_source=github.com&utm_medium=referral&utm_content=XavierJiezou/ys-dl&utm_campaign=Badge_Grade)
[![codecov](https://codecov.io/gh/XavierJiezou/ys-dl/branch/main/graph/badge.svg?token=AFQB7E7JID)](https://codecov.io/gh/XavierJiezou/ys-dl)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/ys-dl)
![PyPI - Downloads](https://img.shields.io/pypi/dm/ys-dl)
![PyPI](https://img.shields.io/pypi/v/ys-dl)
[![GitHub stars](https://img.shields.io/github/stars/XavierJiezou/ys-dl)](https://github.com/XavierJiezou/ys-dl/stargazers)
[![GitHub forks](https://img.shields.io/github/forks/XavierJiezou/ys-dl)](https://github.com/XavierJiezou/ys-dl/network)
[![GitHub issues](https://img.shields.io/github/issues/XavierJiezou/ys-dl)](https://github.com/XavierJiezou/ys-dl/issues)
[![GitHub license](https://img.shields.io/github/license/XavierJiezou/ys-dl)](https://github.com/XavierJiezou/ys-dl/blob/main/LICENSE)

## Demo

![demo](image/demo.png)

## Features

- [x] Download icon image.
- [x] Download background image.
- [x] Download cosplay image.
- [x] Download fan works image.
- [x] Download ranking images.
- [ ] Downlaod topic images.

## Install

```bash
pip install ys-dl
```

## Usage

`$ ys-dl`

- Download cosplay images

```bash
ys-dl cos
```

- Download fan works images

```bash
ys-dl fan
```

- Download ranking images.

```bash
ys-dl rank
```

## Changelog

See [CHANGELOG.md](CHANGELOG.md)

## License

[MIT License](License)

## References

[![Readme Card](https://github-readme-stats.vercel.app/api/pin/?username=python-poetry&repo=poetry)](https://github.com/python-poetry/poetry)
[![Readme Card](https://github-readme-stats.vercel.app/api/pin/?username=SeleniumHQ&repo=selenium)](https://github.com/SeleniumHQ/selenium)
[![Readme Card](https://github-readme-stats.vercel.app/api/pin/?username=psf&repo=requests)](https://github.com/psf/requests)
[![Readme Card](https://github-readme-stats.vercel.app/api/pin/?username=Textualize&repo=rich)](https://github.com/Textualize/rich)
[![Readme Card](https://github-readme-stats.vercel.app/api/pin/?username=google&repo=python-fire)](https://github.com/google/python-fire)
[![Readme Card](https://github-readme-stats.vercel.app/api/pin/?username=pytest-dev&repo=pytest)](https://github.com/pytest-dev/pytest)
